/*
 * KDEPIC - KDE PIC Support
 * Copyright (C) 2007 Ruben Lopez <r.lopez@bren.es>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * ----------------------------------------------------------------------------
 */

#include "kfile_pic.h"

#include <qfile.h>
#include <qvalidator.h>

#include <kdebug.h>
#include <kgenericfactory.h>

#include "pic_rw.h"

typedef KGenericFactory<KPicPlugin> PicFactory;

K_EXPORT_COMPONENT_FACTORY(kfile_pic, PicFactory("kfile_pic"))


KPicPlugin::KPicPlugin(QObject *parent, const char *name, const QStringList &args) :
	KFilePlugin(parent, name, args)
{
	KFileMimeTypeInfo* info = addMimeTypeInfo("image/x-pic");

	KFileMimeTypeInfo::GroupInfo* group = 0;
	KFileMimeTypeInfo::ItemInfo* item;


	group = addGroupInfo(info, "Comment", i18n("Comment"));

	item = addItemInfo(group, "ImageName", i18n("Name"), QVariant::String);
	setAttributes(item, KFileMimeTypeInfo::Modifiable);
	setHint(item, KFileMimeTypeInfo::Description);


	group = addGroupInfo(info, "Technical", i18n("Technical Details"));

	item = addItemInfo(group, "Dimensions", i18n("Dimensions"), QVariant::Size);
	setHint(item, KFileMimeTypeInfo::Size);
	setUnit(item, KFileMimeTypeInfo::Pixels);

	item = addItemInfo(group, "BitDepth", i18n("Bit Depth"), QVariant::Int);
	setUnit(item, KFileMimeTypeInfo::BitsPerPixel);

	item = addItemInfo(group, "ColorMode", i18n("Color Mode"), QVariant::String);
	item = addItemInfo(group, "SharedRows",
			i18n("percentage of avoided vertical redundancy (the higher the better)",
			"Shared Rows"), QVariant::String);

}


bool KPicPlugin::readInfo(KFileMetaInfo& info, uint /*what*/)
{
	std::string imageFile = info.path().ascii();
	PICHeader header;
	
	QFile dev( info.path().latin1() );
    dev.open( IO_ReadOnly );
	
	picReadHeader(&dev, &header);

	dev.close();

	unsigned xsize = header.width;
	unsigned ysize = header.height;

	KFileMetaInfoGroup group;

	group = appendGroup(info, "Technical");

	appendItem(group, "Dimensions", QSize(xsize, ysize));
	appendItem(group, "BitDepth", 32);

	appendItem(group, "ColorMode", i18n("RGB/Alpha"));

	group = appendGroup(info, "Comment");
	appendItem(group, "ImageName", header.comment);
	
	return true;
}


bool KPicPlugin::writeInfo(const KFileMetaInfo& info) const
{
	return false;
}
